/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.field.type;

import java.awt.BorderLayout;
import javax.swing.*;
import nl.cloudfarming.client.field.model.ActivityField;
import nl.cloudfarming.client.geoviewer.render.GeometricalsPreviewPanel;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.netbeans.core.spi.multiview.CloseOperationState;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.netbeans.core.spi.multiview.MultiViewElementCallback;
import org.openide.awt.UndoRedo;
import org.openide.util.ImageUtilities;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;
import org.openide.windows.TopComponent;

/**
 * Visual tab for ActivityField Displays the geometries of it's TreatmentZones
 *
 * @author Merijn Zengers
 */
@MultiViewElement.Registration(displayName = "#LBL_ActivityField_VISUAL",
iconBase = "nl/cloudfarming/client/field/type/folder_treatmentzones.png",
mimeType = ActivityField.MIMETYPE,
persistenceType = TopComponent.PERSISTENCE_NEVER,
preferredID = "ActivityFieldVisual",
position = 2000)
@NbBundle.Messages(value = {
    "LBL_ActivityField_VISUAL=Visual",
    "Title_ActivityField_visual=Activity field visual preview"
})
public class ActivityFieldVisualElement extends JPanel implements MultiViewElement {

    private JToolBar toolbar = new JToolBar();
    private transient MultiViewElementCallback callback;
    private final Lookup lookup;
    private final ActivityField activityField;
    private ASBodyPanel contentPanel;

    public ActivityFieldVisualElement(Lookup lookup) {
        this.lookup = lookup;
        activityField = lookup.lookup(ActivityField.class);
        assert activityField != null : "ActivityField should be in the lookup";
    }

    @Override
    public JComponent getVisualRepresentation() {
        if (contentPanel == null) {
            this.setLayout(new BorderLayout());
            contentPanel = new ASBodyPanel(new GeometricalsPreviewPanel(activityField.getGeometricals()));
            contentPanel.setTitle(Bundle.Title_ActivityField_visual());
            contentPanel.setIcon(new ImageIcon(activityField.getIcon()));
            add(contentPanel);
        }
        return this;
    }

    @Override
    public JComponent getToolbarRepresentation() {
        return toolbar;
    }

    @Override
    public Action[] getActions() {
        return new Action[0];
    }

    @Override
    public Lookup getLookup() {
        return lookup;
    }

    @Override
    public void componentOpened() {
    }

    @Override
    public void componentClosed() {
    }

    @Override
    public void componentShowing() {
        if (callback != null) {
            updateName();
        }
    }
    
    /**
     * Displays tab-name when component is showed.
     */
    private void updateName() {
        if (callback != null) {
            TopComponent tc = callback.getTopComponent();
            tc.setHtmlDisplayName(activityField.getName());
            tc.setDisplayName(activityField.getName());
            tc.setName(getName());
            tc.setToolTipText(getToolTipText());
        }
    }

    @Override
    public void componentHidden() {
    }

    @Override
    public void componentActivated() {
    }

    @Override
    public void componentDeactivated() {
    }

    @Override
    public UndoRedo getUndoRedo() {
        return UndoRedo.NONE;
    }

    @Override
    public void setMultiViewCallback(MultiViewElementCallback mvec) {
        this.callback = mvec;
    }

    @Override
    public CloseOperationState canCloseElement() {
        return CloseOperationState.STATE_OK;
    }
}
