/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.field.type;

import java.awt.Color;
import java.beans.PropertyChangeEvent;
import java.beans.PropertyChangeListener;
import nl.cloudfarming.client.field.model.OnOff;
import nl.cloudfarming.client.field.model.TreatmentZone;
import nl.cloudfarming.client.geoviewer.Palette;

/**
 * Convert a TreatmentZone OnOff value to a display color.
 * 
 * @author johan
 */
public class OnOffPalette extends Palette<OnOff> implements PropertyChangeListener {

    public OnOffPalette(TreatmentZone tzn) {
        super(Color.RED);
        setBaseColorFromValue(tzn.getValue());
        tzn.addPropertyChangeListener(TreatmentZone.PROP_VALUE, this);
    }
    
    private void setBaseColorFromValue(Double tznValue) {
        OnOff oo = OnOff.find(tznValue);
        setBaseColor(getColorForValue(oo));
    }

    @Override
    public final Color getColorForValue(OnOff value) {
        return value == OnOff.OFF ? Color.WHITE : Color.BLACK;
    }

    @Override
    public void propertyChange(PropertyChangeEvent evt) {
        setBaseColorFromValue((Double)evt.getNewValue());
    }
    
}
