/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.field.type;

import com.vividsolutions.jts.geom.Geometry;
import java.util.logging.Logger;
import nl.cloudfarming.client.field.model.ActivityField;
import nl.cloudfarming.client.field.model.TreatmentZone;
import nl.cloudfarming.client.geoviewer.SplitGeometryHandler;
import nl.cloudfarming.client.model.EntityCache;
import org.openide.nodes.Node;
import org.openide.util.Lookup;

/**
 * Split handler for {@link TreatmentZone}
 * @author johan
 */
public class TreatmentZoneSplitHandler extends SplitGeometryHandler {
    private static final Logger LOG = Logger.getLogger("nl.cloudfarming.client.field.type");
    private final TreatmentZone sourceTreatmentZone;

    public TreatmentZoneSplitHandler(TreatmentZone treatmentZone) {
        this.sourceTreatmentZone = treatmentZone;
    }

    @Override
    public Geometry getSource() {
        return sourceTreatmentZone.getGeometry();
    }

    @Override
    public boolean handle(Geometry[] geometries, Node sourceNode) {
        ActivityField activityField = sourceTreatmentZone.getParent();
        
        if (activityField == null) {
            LOG.warning("split requested on orphan treatmentzone");
            return false;
        }

        for (int i = 0; i < geometries.length; i++) {
            // create new tzn based on original tzn and new geometry,
            TreatmentZone newTreatmentZone = new TreatmentZone(sourceTreatmentZone);
            newTreatmentZone.setGeometry(geometries[i]);
            newTreatmentZone.setName(sourceTreatmentZone.getName() + "-part-" + i);
            
            // add to same ActivityField as original:
            activityField.addTreatmentZone(newTreatmentZone);
            
            addToMap(new TreatmentZoneNode(newTreatmentZone));
        }
        removeFromMap(sourceNode);
        // TZN has no validity period like cropfield does, delete it:
        activityField.removeTreatmentZone(sourceTreatmentZone);
        EntityCache.getInstance().remove(sourceTreatmentZone);
        
        return true;
    }
        
}
