/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.field.type.wizard;

import java.awt.BorderLayout;
import java.util.List;
import javax.swing.*;
import nl.cloudfarming.client.geoviewer.Geometrical;
import nl.cloudfarming.client.geoviewer.render.GeometricalsPreviewPanel;
import org.openide.awt.Mnemonics;
import org.openide.util.NbBundle;

/**
 * 
 * @author Maciek
 */
@NbBundle.Messages({
    "GeometricalTaskObjectSelectVisualSummaryPanel_label_text_selection=Selection:",
    "GeometricalTaskObjectSelectVisualSummaryPanel_label_text_from_farm=From farm:",
    "GeometricalTaskObjectSelectVisualSummaryPanel_label_text_caption=Please review your selection before pressing finish.",
    "GeometricalTaskObjectSelectVisualSummaryPanel_label_text_selection_preview=Selection preview:",
    "GeometricalTaskObjectSelectVisualSummaryPanel_label_text_summary_text=Please review your selection before pressing finish.",
    "GeometricalTaskObjectSelectVisualSummaryPanel_label_text_invalid_state=No items selected. Please go back and select one item.", 
    "GeometricalTaskObjectSelectVisualSummaryPanel_panel_name=Summary"
})
public final class GeometricalSelectSummaryPanel extends JPanel {

    private JLabel labelSelection;
    private JLabel labelFromFarm;
    private JLabel selectedFarm;
    private JLabel labelCaption;
    private JLabel labelSelectionPreview;
    private JList listSelection;
    private JScrollPane scrollPaneSelection;
    private JPanel previewPanel;

    /**
     * Creates new form GeometricalTaskObjectSelectVisualSummaryPanel
     */
    public GeometricalSelectSummaryPanel() {
        initComponents();
    }

    @Override
    public String getName() {
        return Bundle.GeometricalTaskObjectSelectVisualSummaryPanel_panel_name();
    }

    /**
     * Method will reset the selectionlist and refresh the previewpanel
     * @param geometricals 
     */
    protected void setGeometricals(List<Geometrical> geometricals){
        
        // Refresh SelectionList
        List<String> geometricalPaths = GeometricalSelectUtil.getGeometricalPaths(geometricals);
        if (geometricalPaths != null) {
            listSelection.removeAll();
            listSelection.setListData(geometricalPaths.toArray());
        }
        
        // Refresh previewPanel
        previewPanel.setLayout(new BorderLayout());
        previewPanel.removeAll();
        previewPanel.add(new GeometricalsPreviewPanel(geometricals));
        previewPanel.validate();
        previewPanel.repaint();
        previewPanel.setVisible(true);
    }
    
    protected void setSelectedProjectPath(String projectPath) {
        selectedFarm.setText(projectPath);
    }

    protected void setValid(boolean valid) {
        labelSelection.setVisible(valid);
        listSelection.setVisible(valid);
        labelFromFarm.setVisible(valid);
        selectedFarm.setVisible(valid);
        labelSelectionPreview.setVisible(valid);
        previewPanel.setVisible(valid);
        showCaptionText(valid);
    }

    private void showCaptionText(boolean valid) {
        if (valid) {
            labelCaption.setText(Bundle.GeometricalTaskObjectSelectVisualSummaryPanel_label_text_summary_text());
        } else {
            labelCaption.setText(Bundle.GeometricalTaskObjectSelectVisualSummaryPanel_label_text_invalid_state());
        }
    }
        
    /**
     * This method is called from within the constructor to initialize the form.
     */
    private void initComponents() {

        labelSelection = new JLabel();
        labelFromFarm = new JLabel();
        selectedFarm = new JLabel();
        labelCaption = new JLabel();
        labelSelectionPreview = new JLabel();
        
        previewPanel = new JPanel();
        scrollPaneSelection = new JScrollPane();
        listSelection = new JList();
        scrollPaneSelection.setViewportView(listSelection);

        Mnemonics.setLocalizedText(labelSelection, Bundle.GeometricalTaskObjectSelectVisualSummaryPanel_label_text_selection()); // NOI18N
        Mnemonics.setLocalizedText(labelFromFarm, Bundle.GeometricalTaskObjectSelectVisualSummaryPanel_label_text_from_farm()); // NOI18N
        Mnemonics.setLocalizedText(labelCaption, Bundle.GeometricalTaskObjectSelectVisualSummaryPanel_label_text_caption()); // NOI18N
        Mnemonics.setLocalizedText(labelSelectionPreview, Bundle.GeometricalTaskObjectSelectVisualSummaryPanel_label_text_selection_preview()); // NOI18N

        GroupLayout previewPanelLayout = new GroupLayout(previewPanel);
        previewPanel.setLayout(previewPanelLayout);
        previewPanelLayout.setHorizontalGroup(
                previewPanelLayout.createParallelGroup(GroupLayout.Alignment.LEADING).addGap(0, 359, Short.MAX_VALUE));
        previewPanelLayout.setVerticalGroup(
                previewPanelLayout.createParallelGroup(GroupLayout.Alignment.LEADING).addGap(0, 239, Short.MAX_VALUE));

        GroupLayout layout = new GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
                layout.createParallelGroup(GroupLayout.Alignment.LEADING).addGroup(layout.createSequentialGroup().addContainerGap().addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING).addGroup(GroupLayout.Alignment.TRAILING, layout.createSequentialGroup().addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING).addGroup(layout.createSequentialGroup().addComponent(labelSelection).addGap(0, 0, Short.MAX_VALUE)).addComponent(scrollPaneSelection, GroupLayout.PREFERRED_SIZE, 0, Short.MAX_VALUE)).addGap(18, 18, 18).addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING).addComponent(previewPanel, GroupLayout.DEFAULT_SIZE, GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE).addComponent(labelSelectionPreview))).addGroup(layout.createSequentialGroup().addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING).addComponent(labelCaption).addGroup(layout.createSequentialGroup().addComponent(labelFromFarm).addPreferredGap(LayoutStyle.ComponentPlacement.RELATED).addComponent(selectedFarm))).addGap(0, 136, Short.MAX_VALUE))).addContainerGap()));
        layout.setVerticalGroup(
                layout.createParallelGroup(GroupLayout.Alignment.LEADING).addGroup(layout.createSequentialGroup().addContainerGap().addComponent(labelCaption).addGap(58, 58, 58).addGroup(layout.createParallelGroup(GroupLayout.Alignment.BASELINE).addComponent(labelFromFarm).addComponent(selectedFarm)).addPreferredGap(LayoutStyle.ComponentPlacement.RELATED).addGroup(layout.createParallelGroup(GroupLayout.Alignment.BASELINE).addComponent(labelSelectionPreview).addComponent(labelSelection)).addPreferredGap(LayoutStyle.ComponentPlacement.UNRELATED).addGroup(layout.createParallelGroup(GroupLayout.Alignment.LEADING).addComponent(previewPanel, GroupLayout.DEFAULT_SIZE, GroupLayout.DEFAULT_SIZE, Short.MAX_VALUE).addComponent(scrollPaneSelection)).addContainerGap()));
    }
}