/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.field.type.wizard;

import java.awt.Component;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.text.MessageFormat;
import java.util.ArrayList;
import java.util.List;
import javax.swing.AbstractAction;
import javax.swing.JComponent;
import nl.cloudfarming.client.field.model.ActivityField;
import nl.cloudfarming.client.field.model.Field;
import org.openide.DialogDisplayer;
import org.openide.WizardDescriptor;
import org.openide.awt.ActionID;
import org.openide.awt.ActionReference;
import org.openide.awt.ActionReferences;
import org.openide.awt.ActionRegistration;
import org.openide.util.NbBundle;

/**
 *
 * @author Timon Veenstra <monezz@gmail.com>
 */
@NbBundle.Messages("NewActivityFieldAction name=New activity field")
@ActionID(category = "Field", id = "nl.cloudfarming.client.field.type.wizard.NewActivityFieldAction")
@ActionRegistration(iconBase = "nl/cloudfarming/client/field/type/folder_treatmentzones.png", displayName = "#NewActivityFieldAction name")
@ActionReferences({
    @ActionReference(path = "Actions/Field", position = 0)
})
public class NewActivityFieldAction extends AbstractAction implements ActionListener {

    private final Field field;

    public NewActivityFieldAction(Field field) {
        putValue(NAME, Bundle.new_activity_field_wizard_title());
        this.field = field;
        verifyFieldGeometry(field);
    }

    @Override
    public void actionPerformed(ActionEvent e) {
        List<WizardDescriptor.Panel<WizardDescriptor>> panels = new ArrayList<>();
        panels.add(new NewActivityFieldWizardPanel(field));
        String[] steps = new String[panels.size()];
        for (int i = 0; i < panels.size(); i++) {
            Component c = panels.get(i).getComponent();
            // Default step name to component name of panel.
            steps[i] = c.getName();
            if (c instanceof JComponent) { // assume Swing components
                JComponent jc = (JComponent) c;
                jc.putClientProperty(WizardDescriptor.PROP_CONTENT_SELECTED_INDEX, i);
                jc.putClientProperty(WizardDescriptor.PROP_CONTENT_DATA, steps);
                jc.putClientProperty(WizardDescriptor.PROP_AUTO_WIZARD_STYLE, true);
                jc.putClientProperty(WizardDescriptor.PROP_CONTENT_DISPLAYED, true);
                jc.putClientProperty(WizardDescriptor.PROP_CONTENT_NUMBERED, true);
            }
        }
        WizardDescriptor wiz = new WizardDescriptor(new WizardDescriptor.ArrayIterator<>(panels));
        // {0} will be replaced by WizardDesriptor.Panel.getComponent().getName()
        wiz.setTitleFormat(new MessageFormat("{0}"));
        wiz.setTitle(Bundle.new_activity_field_wizard_title());
        if (DialogDisplayer.getDefault().notify(wiz) == WizardDescriptor.FINISH_OPTION) {
            String activityFieldName = wiz.getProperty(NewActivityFieldWizardPanel.PROP_ACTIVITY_FIELD_NAME).toString();
            ActivityField activityField = new ActivityField(field.getURI(), activityFieldName, field.getGeometry());
            activityField.setDescription(wiz.getProperty(NewActivityFieldWizardPanel.PROP_ACTIVITY_FIELD_DESCRIPTION).toString());
            field.addActivityField(activityField);
        }
    }

    /**
     * Disable this action if the selected field does not have a geometry.
     *
     * @param field The field the user wishes to add an activityField to
     */
    private void verifyFieldGeometry(Field field) {
        if (field.getGeometry() == null) {
            setEnabled(false);
        }
    }
}
